from functools import partial
import sched


class scheduler(sched.scheduler):
    def repeat(self, interval, priority, action, argument=None, kwargs=None):
        """A variant of enter that re-enters itself."""
        argument = argument if argument else ()
        kwargs = kwargs if kwargs else {}

        partial_action = partial(action, *argument, **kwargs)

        def repeater(action):
            action()
            self.enter(interval, priority, repeater, (partial_action,))

        s.enter(interval, priority, repeater, (partial_action,))

    def every(self, interval, priority):
        """A variant of repeat as a decorator."""
        return partial(self.repeat, interval, priority)



# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['sched2']
setup_kwargs = {
    'name': 'sched2',
    'version': '0.1.0',
    'description': 'Event scheduler',
    'long_description': None,
    'author': 'Pedro Rodrigues',
    'author_email': 'medecau@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/medecau/sched2',
    'py_modules': modules,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
